/*
Theme Name: ReCreo Child Theme
Theme URI: http: //recreo.com/
Description: Child theme for ReCreo
Author: ReCreo
Author URI: http: //recreo.com/
Template: recreo
Version: 0.1
*/
body, .wpb_wrapper p, .wpb_wrapper p strong, .wpb_wrapper p em, .mision .wpb_wrapper p em, #footer-outer #footer-widgets .col input[type=submit], .icon-correo, .icon-telefono, .ascend #footer-outer .widget h4, .ascend #sidebar h4, body[data-form-style="minimal"] .minimal-form-input label span.text .text-inner { font-family: 'Fira Sans' !important;  }

body[data-header-resize="0"] .container-wrap { padding-top: 0px;}
html .container-wrap, .project-title, html .ascend .container-wrap, html .ascend .project-title, html body .vc_text_separator div,
html .carousel-wrap[data-full-width="true"] .carousel-heading, html .carousel-wrap span.left-border, html .carousel-wrap span.right-border,
.single-post.ascend #page-header-bg.fullscreen-header, .single-post #single-below-header.fullscreen-header, html #page-header-wrap,
html .page-header-no-bg, html #full_width_portfolio .project-title.parallax-effect, html .portfolio-items .col,
html .page-template-template-portfolio-php .portfolio-items .col.span_3,
html .page-template-template-portfolio-php .portfolio-items .col.span_4 {background-color: #fff !important;}
body #header-outer, .headercustom { border-top: 8px solid #47bbc8 !important; padding-top: 20px !important;}
header#top #logo { margin-left: 5%;}
header#top #logo img { max-height: 250px}


/* HEADER */
.encabezado { margin-bottom: 0px;}
.encabezado img { border-bottom: 8px solid #47bbc8 !important;}
#header-outer[data-lhe="default"] header#top nav > ul > li > a { padding-top: 0 !important; text-transform: uppercase;
    font-size: 18px;}
.mision .wpb_wrapper p, .wpb_wrapper p {
  font-size: 19px;
  line-height: 1.7;
  font-weight: 300 !important;
  color: #888 !important;
}
.mision .wpb_wrapper p {  text-align: center; width: 90%; margin: 0 auto; max-width: 900px;}
.mision .wpb_wrapper p strong, .wpb_wrapper p strong { color:  #47bbc8 !important; font-weight: 300;}
.mision .wpb_wrapper p em, .wpb_wrapper p em { font-weight:400; font-style: normal; font-size: 19px;}

body h2 {letter-spacing: -0.02em; text-align: center;}
body .encabezado h2 { margin-bottom: 30px;}

.linea { width: 95%; height: 1px; display: block; margin: 0 auto; background: #47bbc8 !important;}
.fototexto img { margin: 0}

/* FORMULARIO */
.forms { float: left; width: 49%; margin: 0 0.5%}
body[data-form-style="minimal"] .minimal-form-input {padding-top: 15px;}
body[data-form-style="minimal"] .minimal-form-input label span.text { margin-top: 10px;}
body[data-form-style="minimal"] .minimal-form-input.filled input, body[data-form-style="minimal"] .minimal-form-input.has-text input,
body[data-form-style="minimal"] .minimal-form-input.filled textarea, body[data-form-style="minimal"] .minimal-form-input.has-text textarea,
#footer-outer #footer-widgets .col input[type=text], #footer-outer #footer-widgets .col input[type=email] { color: #000; font-weight: 400}
body[data-form-style="minimal"] .minimal-form-input label span.text .text-inner {font-weight: 300}
body input[type=text], body textarea, body input[type=email], body input[type=password],
body input[type=tel], body input[type=url], body input[type=search], body input[type=date] { margin-bottom:5px !important; border-bottom: 0;box-shadow:none;}
body textarea.wpcf7-textarea { max-width: 99%; margin: 0 .5%;}

input[type="text"], textarea, input[type="email"], input[type="password"], input[type="tel"], input[type="url"], input[type="search"], input[type="date"] {font-size: 15px; color: #000;}

.wpcf7-form-control-wrap.your-message { clear:both;}

/* FOOTER */
body[data-footer-reveal="1"][data-footer-reveal-shadow="large_2"] #footer-outer .row {padding: 20px 0px;}
.ascend #footer-outer .widget h4, .ascend #sidebar h4 { margin-bottom: 0;font-size: 19px; color: #fff !important;}
#footer-outer .widget a { display: block; font-size: 21px; line-height: 1.5; font-weight: 400; padding-bottom: 7px;}
#footer-widgets .span_6 { padding: 2%}
#footer-outer #footer-widgets .col input[type=submit] {padding: 10px 20px; margin-top: -10px; font-weight: 500; float: right;}
.logo-footer { display: block; background: url('logo-footer.png'); width: 180px; height: 160px;}

.icon-correo { display: block; background: url('icon-mail.png') no-repeat; background-position: 5px 9px; padding-left: 40px; }
.icon-telefono { display: block; background: url('icon-cel.png') no-repeat; background-position: 10px 2px; padding-left: 38px; width: 100%; text-align: left; margin-bottom: 20px; }

body .wpcf7 .wpcf7-response-output {background: none !important; padding:10px; color:#fff !important}

/* RESPONSIVE */
@media only screen and (min-width: 1000px) {
  .container { max-width: 1380px !important;}
}
@media (min-width: 690px) {
  .col { margin-right: 0;}
}
