

/*
/*  We added some css in below for change theme's fonts to Arabic.
/*  If you want to use them, you can copy them in your child theme
/*  or directly comment out below lines!
*/

/******************* Arabic font *******************/

/*
	@import url(http://fonts.googleapis.com/earlyaccess/droidarabicnaskh.css);

	body{font-family: 'Droid Arabic Naskh',serif ;}
	h1, h2, h3, h4, h5, h6{font-family: 'Droid Arabic Naskh',serif ;}
	article.post.quote .post-content h2, article.post.link .post-content h2, article.post.format-status .post-content h2{   font-size: 24px;
		line-height: 40px;}
	#page-header-bg h1, .nectar-box-roll .overlaid-content h1{font-family: 'Droid Arabic Naskh',serif ;font-size: 36px;}
	body h1.light, body h2.light, body h3.light, body h4.light, body h5.light, body h6.light, p.light{font-family: 'Droid Arabic Naskh',serif ;}
	.nectar-button{font-family: 'Droid Arabic Naskh',serif ;}
	.related.products h2, .upsells.products h2, #comments h2, #review_form h3, .cart_totals h2, .shipping_calculator h2, .cross-sells h2, .cart-collaterals h2 {
		font-size: 22px !important;
		line-height: 40px !important;
	}
	.woocommerce form .form-row input.input-text, .woocommerce form .form-row textarea{line-height: 1.8;}
	.woocommerce ul.products li.product .price{font-family: 'Droid Arabic Naskh',serif ;}
	.woocommerce ul.products li.product h3, .woocommerce-page ul.products li.product h3{font-family: 'Droid Arabic Naskh',serif ;}
	.swiper-slide .content h2{font-family: 'Droid Arabic Naskh',serif ;font-size: 52px;}
	.swiper-slide .content p{font-family: 'Droid Arabic Naskh',serif ;}
	.swiper-slide .button a{font-family: 'Droid Arabic Naskh',serif ;}
	body .carousel-wrap[data-full-width="true"] .carousel-heading h2{font-family: 'Droid Arabic Naskh',serif ;}
	#page-header-bg .subheader, .nectar-box-roll .overlaid-content .subheader{font-family: 'Droid Arabic Naskh',serif ;}
	blockquote{font-family: 'Droid Arabic Naskh',serif ;}
*/

body {
    direction: rtl;
    unicode-bidi: embed;
}

code, pre {
    direction: ltr;
    text-align: left;
}

.row {
    direction: ltr;
    text-align: right;
}

.vc_row-fluid, .wpb_row, .full-width-content, .nectar-slider-wrap {
    direction: ltr;
}

#portfolio-extra {
    direction: ltr;
}

.nectar-progress-bar, #page-header-bg .col, .nectar-milestone, .swiper-wrapper, .nectar-social {
    direction: rtl;
}

input[type="text"], textarea, input[type="email"], input[type="password"], input[type="tel"], input[type="url"], input[type="search"], input[type="date"] {
    direction: rtl;
}

#sidebar, #footer-outer .widget, .post, .post-header, #single-below-header, #portfolio-filters-inline, blockquote, #portfolio-filters {
    direction: rtl;
}

.row .col.section-title.project-title, .row .col.section-title.blog-title, .wpb_text_column, #commentform .row, #post-area {
    direction: rtl;
}

html .woocommerce .woocommerce-message, html .woocommerce .woocommerce-error, html .woocommerce .woocommerce-info, .product, .woocommerce .woocommerce-ordering, .img-with-aniamtion-wrap {
    direction: rtl;
}

.nectar-button, .toggles, .tabbed, * > ul > li, .pricing-column, .nectar-fancy-ul ul li, header#top #logo.no-image, .sf-menu li, h1, h2, h3, h4, h5, h6, p, .woocommerce {
    direction: rtl;
}

.nectar-flip-box .flip-box-back .inner, .nectar-flip-box .flip-box-front .inner {
    direction: rtl;
}

.container {
    direction: ltr;
}

.sf-menu {
    direction: rtl;
}

#call-to-action .container {
    direction: rtl;
}

body .portfolio-filters-inline .container {
    direction: rtl;
}

.wpb_row .nectar-parallax-scene li {
    direction: ltr;
}

.comments-section {
    direction: ltr;
}

.woocommerce ul.products li, .woocommerce-page ul.products li {
    direction: rtl;
}

.swiper-slide .content p, .swiper-slide .content h2, .swiper-slide .content .buttons {
    direction: rtl;
}

.woocommerce > form, .woocommerce > form .row {
    direction: rtl;
}

.row #post-area > article .post-content .content-inner {
    direction: ltr;
}

.row #post-area > article .post-content .content-inner * {
    direction: rtl;
}

html body[data-header-format="left-header"] #header-outer .cart-menu-wrap .cart-menu {
    direction: ltr;
}

html body[data-header-format="left-header"] #header-outer .cart-menu-wrap .cart-menu * {
    direction: rtl;
}

* {
    letter-spacing: 0 !important;
}

#footer-outer .widget h4, #sidebar h4, #call-to-action .container a, .uppercase, .nectar-button, body .widget_calendar table th, body #footer-outer #footer-widgets .col .widget_calendar table th,
.swiper-slide .button a, header#top nav > ul > li.megamenu > ul > li > a, .carousel-heading h2, body .gform_wrapper .top_label .gfield_label, body .vc_pie_chart .wpb_pie_chart_heading,
#infscr-loading div, #page-header-bg .author-section a, .ascend input[type="submit"], .ascend button[type="submit"], .widget h4, .text-on-hover-wrap .categories a,
.text_on_hover.product .add_to_cart_button, .woocommerce-page div[data-project-style="text_on_hover"] .single_add_to_cart_button,
.woocommerce div[data-project-style="text_on_hover"] .cart .quantity input.qty, .woocommerce-page #respond input#submit, .meta_overlaid article.post .post-header h2,
.meta_overlaid article.post.quote .post-content h2, .meta_overlaid article.post.link .post-content h2, .meta_overlaid article.post.format-status .post-content h2,
.meta_overlaid article .meta-author a, .pricing-column.highlight h3 .highlight-reason, .blog-recent[data-style="minimal"] .col > span {
    letter-spacing: 0 !important;
}

header#top nav > ul.buttons > li {
    float: left;
}

header#top nav > ul > li {
    float: right;
}

.sf-menu .sf-with-ul a {
    padding-left: 16px !important;
    padding-right: 1em !important;
}

.sf-sub-indicator {
    right: 8px;
    left: 8px;
}

header#top nav ul li a {
    text-align: right;
}

.sf-menu li:hover ul, .sf-menu li.sfHover ul {
    right: 0;
    left: auto;
}

.sf-menu li li ul {
    right: 16em !important;
    left: auto !important;
}

header#top #logo.no-image {
    text-align: left;
}

.swiper-container .slider-next .slide-count {
    right: auto;
}

.swiper-slide .buttons > div:first-child {
    padding-right: 0px;
    padding-left: 8px;
}

.swiper-slide .buttons > div:last-child {
    padding-left: 0px !Important;
    padding-right: 8px !Important;
}

.masonry-blog-item .post-meta .date {
    float: right;
}

.masonry-blog-item .post-meta .nectar-love-wrap {
    float: left;
}

body .masonry.meta_overlaid article.post .post-header .meta-author a {
    margin-right: 4px;
    margin-left: 0;
}

.masonry-blog-item .post-meta .nectar-love-wrap a {
    margin-left: 0 !important;
}

.single-post #single-below-header.fullscreen-header > span {
    float: right;
}

article.post.quote .post-content .quote-inner span.icon, article.post.link .post-content .link-inner span.icon {
    left: 20px;
    right: auto;
}

.iwithtext .iwt-icon {
    right: 0;
    left: auto;
}

.iwithtext .iwt-text {
    padding-right: 55px;
    padding-left: 0;
}

.work-item .work-info .bottom-meta {
    text-align: right;
}

.toggle h3 a i {
    right: 13px;
    left: auto;
}

h3 [class^="icon-"], h2 [class^="icon-"], h4 [class^="icon-"], h5 [class^="icon-"] {
    margin-left: 5px;
    margin-right: auto;
}

.toggle h3 a {
    padding: 14px 43px 16px 14px;
}

.nectar-progress-bar span strong {
    left: 0;
    right: auto;
}

.team-member {
    text-align: right;
}

.team-member ul.social li {
    float: right;
}

.team-member ul.social li:first-child a {
    margin-right: 0;
    margin-left: auto;
}

.team-member ul.social li:last-child:before {
    content: " " !important;
}

#sort-portfolio i {
    left: 5px;
    right: auto;
}

#sort-portfolio span {
    padding-right: 0px !important;
}

#portfolio-filters #sort-portfolio {
    padding-left: 40px;
    padding-right: 15px;
}

#portfolio-filters {
    float: left;
}

.portfolio-items .nectar-love-wrap {
    float: left;
    text-align: left;
}

.portfolio-items .work-meta {
    float: right;
    text-align: right;
}

#portfolio-filters-inline .container > ul {
    float: left;
    margin-left: -10px !important;
    margin-right: auto !important;
}

#portfolio-filters-inline #current-category {
    float: right;
    padding-right: 3px;
}

.pricing-column {
    float: right;
}

#sidebar .widget .tagcloud a, .post-tags a {
    float: right;
    margin: 3px 0 0 3px;
}

.widget_search .search-form input[type="submit"], .newsletter-widget form input[type="submit"] {
    left: 0;
    right: auto;
}

.widget_search .search-form input[type="text"], .newsletter-widget form input[type="email"] {
    padding-left: 75px !important;
    padding-right: 0 !important;
}

.row .col.section-title span {
    padding-right: 10px;
    padding-left: 0;
}

.recent_posts_extra_widget .post-widget-image {
    float: right;
    margin-left: 10px;
    margin-right: auto;
}

.project-attrs li i {
    text-align: right;
}

.nectar-social > * {
    border-left: 1px solid #CCCCCC;
    border-right: none;
}

.nectar-social > *:first-child, .nectar-social .nectar-love {
    padding-right: 0 !important;
}

.nectar-social > *:last-child {
    border-left: 0 none !important;
    padding-left: 0 !important;
    padding-right: 10px !important;
}

.nectar-fancy-ul ul li {
    padding-right: 40px;
    padding-left: 0;
}

.nectar-fancy-ul ul {
    margin-right: 0 !important;
}

.col.centered-text ul, .wpb_column.centered-text ul {
    text-align: right;
}

.nectar-fancy-ul ul li i {
    right: 0;
    left: auto;
}

.single #single-meta {
    left: 0;
    right: auto;
}

.single #single-meta ul li {
    float: right;
}

body.single-portfolio #sidebar #project-meta ul li:first-child, body.single #single-meta ul li:first-child, body.single-portfolio #sidebar div ul .facebook-share, body.single-portfolio #sidebar div ul .twitter-share, body.single-portfolio #sidebar div ul .pinterest-share, body.single-post .blog-title #single-meta ul .facebook-share, body.single-post .blog-title #single-meta ul .twitter-share, body.single-post .blog-title #single-meta ul .pinterest-share, body.single-product #single-meta ul .facebook-share, body.single-product #single-meta ul .twitter-share, body.single-product #single-meta ul .pinterest-share {
    margin-top: 2px;
    margin: 0px 0 0px 16px;
    border-left: 1px solid #DDDDDD;
    border-right: none;
}

.single #single-meta ul li.meta-share-count span, .single #project-meta ul li.meta-share-count span {
    padding-right: 0;
}

.single #single-meta ul li.meta-share-count span.plural, .single #single-meta ul li.meta-share-count span.singular {
    padding-right: 3px !important;
    padding-left: 0 !important;
}

.single-portfolio #project-meta .sharing li:last-child, body.single-post .blog-title #single-meta ul li:last-child, body.single-product #single-meta ul li:last-child {
    margin-right: 5px !important;
    margin-left: 0px !important;
    padding-right: 0px !important;
    border-left: 0px !important;
}

.single #single-meta ul li.meta-share-count .nectar-social, #project-meta ul li.meta-share-count .nectar-social {
    text-align: left;
    right: auto !important;
    left: 0;
}

.single #single-meta li .n-shortcode, .single #single-meta li .nectar-love {
    padding-right: 0px !important;
}

.nectar-love span {
    padding-right: 0px !important;
}

.single #single-below-header span {
    float: right;
}

.single #single-below-header span:first-child {
    padding-left: 10px;
}

.single #single-below-header span:last-child {
    padding-left: 0;
}

#single-below-header a {
    display: inline-block;
}

.masonry.classic_enhanced .posts-container article.has-post-thumbnail .meta-category a {
    right: 20px;
    left: auto;
}

#post-area.masonry.classic_enhanced article.post .post-meta > * {
    margin-right: 0 !important;
    margin-left: 13px !important;
}

#post-area.masonry.classic_enhanced article.post .post-meta > *:last-child {
    margin-left: 0 !important;
}

.masonry.classic_enhanced .masonry-blog-item .post-meta .nectar-love-wrap .nectar-love i, .masonry.classic_enhanced .masonry-blog-item .post-meta .nectar-love-wrap .nectar-love .heart-wrap, .masonry.classic_enhanced .masonry-blog-item .post-meta .nectar-love-wrap .nectar-love .nectar-love-count {
    float: right;
}

.masonry.classic_enhanced article.post .post-meta i {
    margin-left: 3px;
    margin-right: 0;
}

.masonry.classic_enhanced .posts-container article:not(.has-post-thumbnail) .meta-category a {
    margin-right: 20px;
    margin-left: 0;
}

.sharing-default-minimal {
    text-align: right;
}

body[data-button-style="rounded"] .sharing-default-minimal .nectar-social > a, body[data-button-style="rounded"] .sharing-default-minimal .nectar-love {
    margin: 10px 0 10px 13px;
}

.sharing-default-minimal .nectar-social > a, .sharing-default-minimal .nectar-love {
    margin: 10px 0 10px 13px;
}

.sharing-default-minimal .total_loves {
    margin-right: 28px;
    margin-left: 0;
    float: left;
}

body .sharing-default-minimal .nectar-love i {
    margin-left: 8px !important;
    margin-right: 0 !important;
}

body .sharing-default-minimal .nectar-love {
    padding: 7px 30px 7px 9px !important;
    margin-left: 10px;
    margin-right: 0;
}

body[data-form-style="minimal"] .minimal-form-input label span.text {
    right: 0;
    left: auto;
}

.single #single-below-header > span {
    border-right: 1px solid #DDDDDD;
    border-left: none;
}

body[data-smooth-scrolling="1"] #full_width_portfolio .project-title.parallax-effect, body[data-smooth-scrolling="1"] #page-header-bg[data-parallax="1"] {
    padding-left: 16px;
    padding-right: 0;
}

#commentform .col {
    float: right;
}

#commentform .col:last-child, #commentform .col.col_last {
    margin-left: 0;
}

.comment-list li.comment > div img.avatar, .comment-list li.pingback > div img.avatar {
    right: 29px;
    left: auto;
}

.comment-list li.comment > div, .comment-list li.pingback > div {
    padding: 25px 116px 25px 25px;
}

.comment-list .reply {
    left: 29px;
    right: auto;
}

.comment-list .children {
    background-position: right 20px !important;
    border-right: 1px solid #DDDDDD;
    border-left: none;
    margin-right: 0 !important;
    padding-right: 40px !important;
    padding-left: 0 !important;
    margin-left: 0 !important;
}

body .icon-tiny[class^="icon-"] {
    margin-left: 5px;
    margin-right: 0;
}

.row.blog-recent .col {
    float: right;
}

.row.blog-recent .col.col_last, .row.blog-recent .col:last-child, .blog-recent div:last-of-type {
    margin-left: 0;
}

#sidebar .widget input[type="text"], #sidebar .widget input[type="email"] {
    padding: 10px !important;
}

.flex-direction-nav li {
    margin-right: 7px !important;
    margin-left: auto !important;
}

.woocommerce .woocommerce-result-count, .woocommerce-page .woocommerce-result-count {
    float: right;
}

.woocommerce .products.related .product, .woocommerce .products.upsells .product {
    margin-left: 2% !important;
    margin-right: 0 !important;
}

.woocommerce #content div.product form.cart div.quantity, .woocommerce div.product form.cart div.quantity, .woocommerce-page #content div.product form.cart div.quantity, .woocommerce-page div.product form.cart div.quantity {
    float: right;
    margin: 0 0 0 4px;
}

.woocommerce #content div.product form.cart .button, .woocommerce div.product form.cart .button, .woocommerce-page #content div.product form.cart .button, .woocommerce-page div.product form.cart .button {
    float: right;
}

.woocommerce div.product form.cart .button, .woocommerce-page div.product form.cart .button, .woocommerce #content div.product form.cart .button, .woocommerce-page #content div.product form.cart .button {
    margin-right: 20px;
    margin-left: 0;
}

.woocommerce .woocommerce-product-rating .star-rating, .woocommerce-page .woocommerce-product-rating .star-rating {
    float: right;
    margin: 0.5em 0 0 4px;
}

.woocommerce-breadcrumb .fa-angle-right:before {
    content: "\f104";
}

.woocommerce .woocommerce-result-count {
    left: 220px;
    right: auto;
}

#copyright .col {
    float: right;
}

#copyright .col.col_last, #copyright .col:last-child {
    margin-left: 0;
}

#footer-outer #copyright .col ul {
    float: left;
}

#footer-outer #copyright li {
    float: right;
    margin-right: 20px;
    margin-left: 0;
}

.woocommerce #reviews #comments ol.commentlist li img.avatar, .woocommerce-page #reviews #comments ol.commentlist li img.avatar {
    right: 25px !important;
    left: auto !important;
}

.woocommerce #reviews #comments ol.commentlist li .comment-text, .woocommerce-page #reviews #comments ol.commentlist li .comment-text {
    margin: 0 50px 0 0;
}

.woocommerce .commentlist li .comment_container .comment-text {
    margin-right: 70px !important;
    margin-left: auto !important;
}

.woocommerce .star-rating, .woocommerce-page .star-rating {
    float: left;
}

.woocommerce p.stars a.star-1:after, .woocommerce p.stars a.star-2:after, .woocommerce p.stars a.star-3:after, .woocommerce p.stars a.star-4:after, .woocommerce p.stars a.star-5:after, .woocommerce-page p.stars a.star-1:after,
.woocommerce-page p.stars a.star-2:after, .woocommerce-page p.stars a.star-3:after, .woocommerce-page p.stars a.star-4:after, .woocommerce-page p.stars a.star-5:after {
    right: 0;
    left: auto;
}

.woocommerce .woocommerce-error .button, .woocommerce .woocommerce-info .button, .woocommerce .woocommerce-message .button, .woocommerce-page .woocommerce-error .button, .woocommerce-page .woocommerce-info .button, .woocommerce-page .woocommerce-message .button {
    float: left;
}

.woocommerce p.stars a:before {
    right: 0;
    left: auto;
}

.checkout .woocommerce-shipping-fields, .checkout .woocommerce-billing-fields {
    padding-left: 45px;
    padding-right: 0;
}

.woocommerce-checkout-review-order-table .product-image {
    float: right;
}

.woocommerce-checkout-review-order-table .product-info {
    padding-left: 30px;
    padding-right: 0;
    float: left;
}

body[data-fancy-form-rcs="1"] [type="radio"]:not(:checked) + label, body[data-fancy-form-rcs="1"] [type="radio"]:checked + label {
    padding-right: 28px;
    padding-left: 0;
    margin-left: 15px;
    margin-right: 0;
}

body[data-fancy-form-rcs="1"] [type="radio"] + label:before, body[data-fancy-form-rcs="1"] [type="radio"] + label:after {
    right: 0;
    left: auto;
}

body[data-fancy-form-rcs="1"] input[type='checkbox'] + label > span {
    right: 0;
    left: auto;
    margin-left: 12px;
    margin-right: 0;
}

body[data-fancy-form-rcs="1"] input[type='checkbox'] + label {
    padding-right: 30px;
    padding-left: 0;
    margin-left: 15px;
    margin-right: 0;
}

body[data-fancy-form-rcs="1"] input[type='checkbox'] {
    left: 9999px;
}

.ascend.single-product #reply-title, .ascend.single-product #commentform .form-submit {
    text-align: right !important;
}

body[data-full-width-header="false"] #slide-out-widget-area a.slide_out_area_close {
    left: 22px;
    right: auto;
}

.wc-forward a:after, .wc-forward:after {
    margin-right: 7px;
    margin-left: auto;
}

.woocommerce table.shop_table, .woocommerce-page table.shop_table {
    margin: 0 0 24px -1px;
    text-align: right;
}

caption, th, td {
    text-align: right;
}

.woocommerce table.cart tr td:first-child {
    padding-right: 0 !important;
    padding-left: 10px !important;
}

.woocommerce #content table.cart td.actions, .woocommerce table.cart td.actions, .woocommerce-page #content table.cart td.actions, .woocommerce-page table.cart td.actions {
    text-align: left;
}

.woocommerce #post-area .woocommerce-ordering {
    float: left !important;
}

.woocommerce .span_9 .woocommerce-ordering {
    left: 0;
    right: auto;
}

.woocommerce-page ul.product_list_widget li img {
    float: right !important;
    margin-left: 15px !important;
    margin-right: 0 !important;
}

.woocommerce #post-area .woocommerce-result-count {
    float: right !important;
}

.woocommerce .span_9 ul.products li.product, .woocommerce-page .span_9 ul.products li.product {
    margin-left: 2%;
    margin-right: 0;
}

.woocommerce ul.products li.product.material, .woocommerce-page ul.products li.product.material {
    margin-left: 1.3%;
    margin-right: 0;
}

.woocommerce .span_9 ul.products li.product.material, .woocommerce-page .span_9 ul.products li.product.material {
    margin-left: 1.3%;
    margin-right: 0;
}

.woocommerce-page ul.products li.product.last, .woocommerce ul.products li.product.last, .woocommerce-page ul.products li.product.material.last, .woocommerce ul.products li.product.material.last {
    margin-left: 0px;
}

.woocommerce .products.related ul.products li.product.last, .woocommerce-page .products.related ul.products li.product.last, .woocommerce-page ul.products li.product.last, .woocommerce ul.products li.product.last {
    margin-left: 0;
}

.iosSlider.product-thumbs .slider {
    direction: ltr;
    text-align: center;
}

.iosSlider.product-thumbs .thumb {
    margin-left: 10px;
    margin-right: 0;
}

.woocommerce div.product .woocommerce-tabs .full-width-content ul.tabs li {
    float: right !important;
}

.single-product .woocommerce-tabs.full-width-tabs {
    direction: ltr;
}

.single-product .woocommerce-tabs.full-width-tabs * {
    direction: rtl;
}

#header-outer .widget_shopping_cart .cart_list a img {
    float: right;
    margin-right: 0 !important;
    margin-left: 14px !important;
}

#header-outer .widget_shopping_cart .cart_list {
    right: auto;
}

body.single-product div.product .product_title {
    padding-right: 0 !important;
}

.nectar-sharing i {
    padding-left: 4px;
    padding-right: 0;
}

.woocommerce .col2-set .col-1, .woocommerce-page .col2-set .col-1 {
    float: right;
}

.woocommerce .col2-set .col-2, .woocommerce-page .col2-set .col-2 {
    float: left;
}

.woocommerce form .form-row-first, .woocommerce form .form-row-last, .woocommerce-page form .form-row-first, .woocommerce-page form .form-row-last {
    float: right;
}

.woocommerce form .form-row-last, .woocommerce-page form .form-row-last {
    float: left;
}

.woocommerce .checkout .col-2 h3#ship-to-different-address, .woocommerce-page .checkout .col-2 h3#ship-to-different-address {
    float: right;
}

.woocommerce #payment ul.payment_methods li, .woocommerce-page #payment ul.payment_methods li {
    text-align: right;
}

.woocommerce form.checkout_coupon, .woocommerce form.login, .woocommerce form.register, .woocommerce-page form.checkout_coupon, .woocommerce-page form.login, .woocommerce-page form.register {
    text-align: right;
}

.woocommerce .order_details li, .woocommerce-page .order_details li {
    float: right;
    margin-left: 2em;
    padding-left: 2em;
    margin-right: 0;
    padding-right: 0;
}

.woocommerce .order_details li, .woocommerce-page .order_details li {
    border-left: 1px dashed #E0DADF;
    border-right: none;
}

.woocommerce table.my_account_orders td, .woocommerce table.my_account_orders th, .woocommerce-page table.my_account_orders td, .woocommerce-page table.my_account_orders th {
    text-align: right !important;
}

.woocommerce-account .addresses .title h3 {
    float: right;
}

.woocommerce table.my_account_orders .order-actions, .woocommerce-page table.my_account_orders .order-actions {
    text-align: left !important;
}

.woocommerce-account[data-fancy-form-rcs="1"] label[for="rememberme"] {
    margin-right: 15px;
}

.woocommerce table.my_account_orders .order-actions .button, .woocommerce-page table.my_account_orders .order-actions .button {
    margin: 0.125em 0.25em 0.125em 0;
}

.wc-backward a:before, .wc-backward:before {
    margin-left: 7px;
    margin-right: auto;
}

.woocommerce .woocommerce-ordering {
    left: 0;
    right: auto;
}

.woocommerce ul.products li.product.text_on_hover .onsale, .woocommerce-page ul.products li.product.text_on_hover .onsale, .woocommerce .text_on_hover.product span.onsale, .woocommerce-page .text_on_hover.product span.onsale, div[data-project-style="text_on_hover"] .single-product-main-image .onsale {
    right: 13px !important;
    left: auto !important;
}

.testimonial_slider .controls ul {
    text-align: center;
}

.post-tags h4 {
    float: right;
    margin-left: 25px;
    margin-right: auto;
}

#author-bio img {
    right: 0;
    left: auto;
}

#author-bio #author-info {
    padding-right: 105px;
    padding-left: 0;
}

.widget_calendar table #prev {
    text-align: right;
}

#page-header-bg[data-alignment="center"] .row {
    text-align: center;
}

#page-header-bg[data-alignment="right"] .row {
    text-align: right;
}

#page-header-bg[data-alignment="left"] .row {
    text-align: left;
}

#pagination .next a, #pagination .next.inactive, #pagination .page-numbers.next, .woocommerce nav.woocommerce-pagination ul li .page-numbers.next {
    direction: rtl;
}

#pagination .prev a, #pagination .prev.inactive, #pagination .page-numbers.prev, .woocommerce nav.woocommerce-pagination ul li .page-numbers.prev {
    direction: rtl;
}

.woocommerce div.product form.cart .variations td.label, .woocommerce #content div.product form.cart .variations td.label, .woocommerce-page div.product form.cart .variations td.label,
.woocommerce-page #content div.product form.cart .variations td.label {
    padding-left: 1em;
    padding-right: 0;
}

.woocommerce .reset_variations {
    left: -200px;
    right: auto;
}

header#top nav > ul > li.megamenu > ul > li ul {
    right: 0 !important;
}

header#top nav > ul > li.megamenu > ul.sub-menu {
    right: 0;
    left: auto;
}

header#top nav > ul > li.megamenu > ul > li {
    border-left: 1px solid rgba(255, 255, 255, 0.08);
    border-right: none;
}

.single.single-post .section-title h1 {
    text-align: right;
}

.team-member[data-style="bio_fullscreen"] .team-meta {
    padding-right: 25px;
    padding-left: 0;
    right: 0;
    left: auto;
    text-align: right;
}

body .team-member[data-style="bio_fullscreen"] .team-meta .arrow-end {
    -ms-transform: translateX(8px) translateY(-50%);
    -webkit-transform: translateX(8px) translateY(-50%);
    transform: translateX(8px) translateY(-50%);
}

.team-member[data-style="bio_fullscreen"]:hover .team-meta .arrow-line, .team-member[data-style="bio_fullscreen"]:hover .team-meta .arrow-end {
    -ms-transform: translateX(0) translateY(-50%);
    -webkit-transform: translateX(0) translateY(-50%);
    transform: translateX(0) translateY(-50%);
}

.team-member[data-style="bio_fullscreen"] .team-meta .arrow-end {
    content: "\f104";
    margin-right: 15px;
    margin-left: 0;
    right: auto;
    left: 0px;
}

body .team-member[data-style="bio_fullscreen"] .team-meta .arrow-end {
    left: 25px;
    right: auto;
}

body .team-member[data-style="bio_fullscreen"] .team-meta .arrow-end.fa-angle-right:before {
    content: "\f104";
}

.team-member[data-style="bio_fullscreen"] .team-meta .arrow-line {
    left: -10px;
    right: auto;
    transform: translateY(-50%) translateX(20px) translateZ(0);
    -webkit-transform: translateY(-50%) translateX(20px) translateZ(0);
}

body .team-member[data-style="bio_fullscreen"] .team-meta .arrow-line {
    left: 27px;
    right: auto;
}

.team-member[data-style="meta_overlaid_alt"] .team-meta {
    text-align: right;
    right: 25px;
    left: auto;
}

.nectar-fancy-box .inner {
    text-align: right;
}

.nectar-fancy-box .link-text {
    text-align: right;
}

.nectar-fancy-box .link-text .arrow {
    margin-right: 16px;
    margin-left: 0;
}

.nectar-fancy-box .link-text {
    direction: rtl;
}

.nectar-fancy-box .link-text .arrow:before {
    content: "\f104";
    left: -1px;
    right: auto;
}

.nectar-fancy-box .link-text .arrow:after {
    right: -6px;
    left: auto;
    transform: translateX(27px);
    -webkit-transform: translateX(27px);
}

.nectar-fancy-box:hover .link-text .arrow:before {
    transform: translateX(-9px);
    -webkit-transform: translateX(-9px);
}

.nectar-fancy-box:hover .link-text .arrow:after {
    transform: translateX(-2px);
    -webkit-transform: translateX(-2px);
}

.testimonial_slider[data-style="multiple_visible"] blockquote p {
    text-align: right;
    padding: 50px 100px 50px 50px;
}

.testimonial_slider[data-style="multiple_visible"] blockquote p:before {
    right: 29px;
    left: auto;
}

.nectar-recent-posts-slider .inner-wrap {
    left: 44%;
    direction: rtl;
}

.nectar-recent-posts-slider .container .strong a {
    margin-right: 15px;
    margin-left: 0;
}

.nectar-recent-posts-slider .container .strong a:first-child {
    margin-right: 0;
}

.nectar-recent-posts-slider .container .strong span::before {
    right: 0;
    margin-left: 4px;
    left: auto;
    margin-right: 0;
}

.nectar-recent-posts-slider .flickity-page-dots {
    text-align: right;
}

.woocommerce ul.products li.product .onsale, .woocommerce-page ul.products li.product .onsale, .woocommerce span.onsale, .woocommerce-page span.onsale {
    left: 15px !important;
    right: auto !important;
}

.woocommerce ul.products li.product .onsale, .woocommerce-page ul.products li.product .onsale {
    margin: -6px 0 0 -6px;
    left: 0;
    right: auto;
}

.woocommerce-page .single-product-main-image .onsale {
    left: 9px !important;
    right: auto !important;
}

.woocommerce .cart-collaterals .shipping_calculator .shipping-calculator-button:after, .woocommerce-page .cart-collaterals .shipping_calculator .shipping-calculator-button:after {
    margin-right: 7px;
    margin-left: auto;
}

.woocommerce .cart-collaterals .cart_totals {
    text-align: right !important;
}

.woocommerce .cart-collaterals .cart_totals {
    float: right !important;
}

.woocommerce .cart-collaterals .shipping_calculator, .woocommerce-page .cart-collaterals .shipping_calculator {
    clear: left;
    float: left;
}

.woocommerce .cart-collaterals .cart_totals table th, .woocommerce-page .cart-collaterals .cart_totals table th {
    padding: 6px 0 0 12px;
}

.sf-menu li {
    float: right;
}

body[data-header-color="dark"] #header-secondary-outer nav > ul > li > a {
    border-right: 1px solid #222222;
    border-left: none;
}

#header-secondary-outer nav > ul > li > a {
    border-right: 1px solid #DDDDDD;
    border-left: none;
}

#header-secondary-outer #social li {
    float: right;
}

body[data-header-color="dark"] header#top nav ul #search-btn > div {
    border-right: 1px solid #333333;
    border-left: none;
}

.woocommerce .span_9.col_last .woocommerce-ordering {
    left: 20px !important;
    right: auto !important;
}

.woocommerce .span_9 .products.related .products li:nth-child(3), .woocommerce .span_9 .products.upsells .products li:nth-child(3) {
    margin-left: 0 !important;
}

.recent_projects_widget div a, #sidebar #flickr div a, #footer-outer #flickr div a {
    float: right;
    margin: 2% 0 0 2%;
}

.recent_projects_widget div a:nth-child(3n+3), #sidebar #flickr div:nth-child(3n+3) a, #footer-outer #flickr div:nth-child(3n+3) a {
    margin-left: 0 !important;
}

#footer-outer #footer-widgets .col .tagcloud a {
    float: right;
    margin: 3px 0 0 3px;
}

#header-secondary-outer nav > ul > li:last-child {
    border-left: 1px solid #DDDDDD;
    border-right: none;
}

.woocommerce td.product-name dl.variation dt, .woocommerce td.product-name dl.variation dd, .woocommerce-page td.product-name dl.variation dt, .woocommerce-page td.product-name dl.variation dd {
    float: right;
}

.woocommerce td.product-name dl.variation dt, .woocommerce-page td.product-name dl.variation dt {
    clear: right;
    margin: 0 0 0 4px;
}

.woocommerce ul.cart_list li dl dt, .woocommerce ul.product_list_widget li dl dt, .woocommerce-page ul.cart_list li dl dt, .woocommerce-page ul.product_list_widget li dl dt {
    clear: right;
    margin: 0 0 0 4px;
}

.woocommerce ul.cart_list li dl dt, .woocommerce ul.cart_list li dl dd, .woocommerce ul.product_list_widget li dl dt, .woocommerce ul.product_list_widget li dl dd, .woocommerce-page ul.cart_list li dl dt, .woocommerce-page ul.cart_list li dl dd,
.woocommerce-page ul.product_list_widget li dl dt, .woocommerce-page ul.product_list_widget li dl dd {
    float: right;
}

.woocommerce ul.cart_list li dl, .woocommerce ul.product_list_widget li dl, .woocommerce-page ul.cart_list li dl, .woocommerce-page ul.product_list_widget li dl {
    border-right: 2px solid rgba(0, 0, 0, 0.1);
    border-left: none;
    padding-right: 1em;
    padding-left: 0;
}

.woocommerce ul.products .material.product span.onsale, .woocommerce-page ul.products .material.product span.onsale {
    right: 22px !important;
    left: auto !important;
}

.woocommerce .material.product .product-wrap .product-add-to-cart {
    right: 20px;
    left: auto;
}

.woocommerce .material.product .product-wrap .product-add-to-cart .price {
    border-left: 1px solid rgba(0, 0, 0, 0.13);
    border-right: 0;
}

.sf-menu li ul li .sf-sub-indicator {
    right: auto;
    left: 14px;
}

.sf-sub-indicator .icon-angle-right:before {
    content: "\f104";
}

body:not(.woocommerce-cart) .main-content th {
    text-align: right;
}

.woocommerce ul.products li.product, .woocommerce-page ul.products li.product {
    float: right;
    margin-left: 2%;
    margin-right: 0;
}

#pagination {
    direction: ltr;
}

#post-area #pagination {
    padding-left: 0;
}

.portfolio-filters-inline #current-category {
    padding-right: 0px;
    float: right;
}

.portfolio-filters-inline .container > ul {
    float: left;
}

.portfolio-filters-inline .container > ul {
    margin-left: -7px !important;
    margin-right: auto !important;
}

.portfolio-filters-inline ul {
    text-align: left;
}

.portfolio-items .work-info {
    right: 0px;
    left: auto;
}

.portfolio-items .work-item.style-3 .vert-center, .portfolio-items .work-item.style-3-alt .vert-center, .portfolio-items .work-item.style-2[data-custom-content="on"] .vert-center {
    right: 50%;
    left: auto;
    transform: translateY(-50%) translateX(50%) !important;
    -webkit-transform: translateY(-50%) translateX(50%) !important;
}

body.single-portfolio #sidebar #project-meta ul li:first-child, body.single #single-meta ul li:first-child, body.single-portfolio #sidebar div ul .facebook-share, body.single-portfolio #sidebar div ul .twitter-share, body.single-portfolio #sidebar div ul .pinterest-share, body.single-post .blog-title #single-meta ul .facebook-share, body.single-post .blog-title #single-meta ul .twitter-share, body.single-post .blog-title #single-meta ul .pinterest-share, body.single-product #single-meta ul .facebook-share, body.single-product #single-meta ul .twitter-share, body.single-product #single-meta ul .pinterest-share {
    border-right: none;
    border-left: 1px solid #DDDDDD;
}

#project-meta ul li {
    float: right;
}

#project-meta ul li.meta-share-count .nectar-social, div[data-tab-pos="fullwidth"] ul li.meta-share-count .nectar-social {
    text-align: right !important;
    right: 0;
    left: auto !important;
}

body .bottom_controls #portfolio-nav .controls li#prev-link a, body .bottom_controls #portfolio-nav .controls li#next-link a {
    direction: ltr;
}

body .bottom_controls #portfolio-nav .controls li#prev-link a span, body .bottom_controls #portfolio-nav .controls li#next-link a span {
    direction: rtl;
}

.single #single-meta ul li.meta-share-count .nectar-social a, #sidebar #project-meta ul li.meta-share-count .nectar-social a {
    padding: 0px 8px !important;
}

body.single-portfolio #sidebar #project-meta ul li:first-child {
    margin-right: 0 !important;
    margin-left: 5px !important;
}

.single #single-meta ul li i, #project-meta ul li i {
    margin-left: 7px;
    margin-right: 0;
}

.nectar-dropcap {
    float: right;
    padding: 5px 0 0px 10px;
}

#post-area.standard-minimal article.post .content-inner .quote-inner .author:before {
    right: 0;
    left: auto;
}

#post-area.standard-minimal article.post .content-inner .quote-inner .author {
    padding-right: 30px;
    padding-left: 0;
}

.single #post-area.standard-minimal .post-content {
    padding-right: 0;
}

#post-area.masonry.classic_enhanced article.post.large_featured .img-link, #post-area.masonry.classic_enhanced article.post.large_featured .nectar-flickity {
    left: 0;
    right: auto;
}

.masonry.classic_enhanced .masonry-blog-item.post.large_featured .article-content-wrap {
    right: 0;
    left: auto;
}

.masonry.classic_enhanced .posts-container article .video-play-button:before {
    width: 63px;
}

.nectar-social.full-width > * {
    float: right;
}

.woocommerce ul.products li, .woocommerce-page ul.products li {
    text-align: right;
}

.woocommerce .material.product {
    text-align: right;
}

.woocommerce ul.products li.text_on_hover.product, .woocommerce-page ul.products li.text_on_hover.product {
    text-align: center;
}

.woocommerce .full-width-content .page-title, .woocommerce .full-width-content .woocommerce-result-count, html .full-width-content .woocommerce-breadcrumb {
    padding-right: 2%;
    padding-left: 0;
}

.woocommerce .full-width-content .woocommerce-result-count {
    margin-left: 2%;
    margin-right: 0;
}

.woocommerce .full-width-content .woocommerce-ordering {
    left: 2%;
    right: auto;
}

.woocommerce .full-width-content .page-title, .woocommerce .full-width-content .woocommerce-result-count {
    padding-right: 2%;
    padding-left: 0;
}

.woocommerce .products.related ul.products li.product.last, .woocommerce-page .products.related ul.products li.product.last {
    margin-left: 0px !important;
}

.woocommerce table.cart tr td:last-child {
    padding-left: 0 !important;
}

.woocommerce-MyAccount-navigation ul li a:before {
    margin-left: 15px;
    margin-right: 0;
    text-align: left;
    float: right;
}

.main-content .woocommerce-MyAccount-navigation ul {
    margin-right: 0;
}

.woocommerce-account .woocommerce-MyAccount-navigation {
    float: right;
}

.woocommerce-account .woocommerce-MyAccount-content {
    float: left;
}

.woocommerce-account .addresses .title .edit, .woocommerce-account ul.digital-downloads li .count {
    float: left;
}

body[data-fancy-form-rcs="1"].woocommerce.woocommerce .woocommerce-ordering {
    float: left;
    margin-right: 20px;
    margin-left: 0;
}

body[data-fancy-form-rcs="1"].woocommerce .woocommerce-result-count {
    left: auto;
    float: left !important;
}

.woocommerce-breadcrumb {
    direction: rtl;
}

.woocommerce div.product .woocommerce-tabs .panel#tab-description {
    direction: ltr;
}

.woocommerce div.product .woocommerce-tabs .panel#tab-description * {
    direction: rtl;
}

.woocommerce .widget_shopping_cart .cart_list li, .woocommerce.widget_shopping_cart .cart_list li {
    padding-right: 2em;
    padding-left: 4px;
}

.nectar-slide-in-cart .widget_shopping_cart .cart_list li {
    padding: 20px 20px;
}

.nectar-slide-in-cart .widget_shopping_cart .cart_list li {
    padding-right: 100px;
    padding-left: 20px;
}

.woocommerce .widget_shopping_cart .cart_list li a.remove, .woocommerce.widget_shopping_cart .cart_list li a.remove {
    float: left;
    margin-right: 15px;
    margin-left: 0;
}

.nectar-slide-in-cart .woocommerce.widget_shopping_cart .cart_list li a.remove {
    left: 0;
    right: auto;
}

.nectar-slide-in-cart .widget_shopping_cart .cart_list a img {
    right: 0px;
    left: auto;
}

.woocommerce .cart .quantity input.plus {
    left: 0;
    right: auto;
}

.woocommerce .cart .quantity input.minus {
    left: 0;
    right: auto;
}

.woocommerce .cart .quantity input.qty, .ascend.woocommerce .cart .quantity input.qty, .ascend .woocommerce .cart .quantity input.qty {
    border: 1px solid #e1e1e1 !important;
    border-left: none !important;
}

.woocommerce.single-product div[data-tab-pos="fullwidth"] #single-meta ul {
    margin-right: 0;
}

.woocommerce .carousel-wrap.products-carousel {
    direction: ltr;
}

.woocommerce .carousel-wrap.products-carousel * {
    direction: rtl;
}

.wishlist_table tr td.product-thumbnail, .wishlist_table tr td.product-name, .wishlist_table tr td.wishlist-name, .wishlist_table tr td.wishlist-privacy, .woocommerce table.wishlist_table tfoot td {
    text-align: right;
}

body.ascend #search-outer #search input[type="text"] {
    line-height: 1.5em;
}

.ascend #header-outer[data-remove-border="true"][data-full-width="true"] header#top nav ul #search-btn > div {
    padding-right: 0;
}

.single.single-post .fullscreen-header .blog-title h1 {
    text-align: center;
}

#page-header-bg.fullscreen-header .author-section .avatar-post-info, #page-header-bg.fullscreen-header .author-section .meta-author {
    text-align: right;
}

#page-header-bg.fullscreen-header .author-section .avatar-post-info {
    margin-right: 10px;
    margin-left: 0;
}

.single-post #single-below-header.fullscreen-header .icon-default-style {
    margin-left: 8px;
    margin-right: 0;
}

.ascend .container-wrap #author-bio #author-info {
    padding-right: 0 !important;
}

#slide-out-widget-area.fullscreen {
    right: 0;
    left: auto;
    padding-left: 20px;
    padding-right: 0;
}

.ascend .comment #reply-title {
    text-align: right !important;
}

#respond h3 .cancel-comment-reply, #respond #cancel-comment-reply-link {
    margin-right: 10px;
    margin-left: 0;
    padding-right: 10px;
    padding-left: 0;
    border-right: 1px solid #ddd;
    border-left: none;
}

.ascend #respond #cancel-comment-reply-link {
    padding-right: 15px;
    padding-left: 0;
}

.main-content ul, .main-content ol {
    margin-right: 30px;
    margin-left: 0;
}

.n-shortcode .nectar-love .icon-salient-heart, .n-shortcode .nectar-love .icon-salient-heart-2 {
    margin-left: 5px;
    margin-right: 0;
}

#project-meta .nectar-love {
    padding-left: 13px !important;
}

.portfolio-items .col .work-info .vert-center .custom-content {
    text-align: right;
}

body .pricing-table[data-style="flat-alternative"] .pricing-column, body .pricing-table[data-style="flat-alternative"] .pricing-column.highlight {
    text-align: right;
    margin-right: 0;
    margin-left: 3.5%;
}

.pricing-table[data-style="flat-alternative"] > div:last-child {
    margin-left: 0 !important;
}

.pricing-table[data-style="flat-alternative"] .pricing-column.highlight h3 .highlight-reason {
    left: auto;
    right: 0;
}

.pricing-table[data-style="flat-alternative"] .pricing-column.highlight h3 .highlight-reason {
    padding-right: 50px;
    padding-left: 0;
}

.pricing-table[data-style="flat-alternative"] .pricing-column .interval:before {
    padding-left: 6px;
    padding-right: 0;
}

body .comment-list {
    margin-right: 0;
}

#call-to-action .container a {
    margin-right: 20px;
    margin-left: 0;
}

h1 .nectar-button, h2 .nectar-button, h3 .nectar-button, h4 .nectar-button {
    margin-right: 13px;
    margin-left: 0;
}

#page-header-bg.fullscreen-header .author-section span {
    padding-right: 0;
}

#sidebar div ul {
    margin-right: 0;
}

.flex-gallery ul {
    margin: 0;
}

article.post .post-meta {
    border-left: 1px solid #E6E6E6;
    border-right: none;
}

article.post.masonry-blog-item .post-meta {
    border-left: 0 !important;
}

article.post .post-meta {
    right: 0;
    left: auto;
}

article.post .article-content-wrap span.meta-category, article.post .article-content-wrap span.meta-author, article.post .article-content-wrap span.meta-comment-count {
    display: inline-block;
}

.post-content {
    padding-left: 0;
    padding-right: 95px;
}

#post-area.standard-minimal .post-content {
    padding-right: 175px;
    padding-left: 0;
}

#post-area.standard-minimal .post-author {
    right: 0;
    left: auto;
}

#post-area.standard-minimal .post-author .meta-category {
    display: inline-block;
}

#post-area.masonry article.post .post-content {
    padding-right: 0 !important;
}

.col.centered-text ul, .wpb_column.centered-text ul {
    margin-right: 0 !important;
}

.single .post-content {
    padding-right: 0;
}

.carousel-heading h2 {
    margin-right: 10px;
    margin-left: 0;
}

.carousel-wrap[data-full-width="false"] .control-wrap {
    left: 5px;
    right: auto;
}

.control-wrap .carousel-prev {
    left: 0px;
    right: auto;
    padding-left: 1px;
    padding-right: 0px;
}

.control-wrap .carousel-next {
    left: 25px;
    right: auto;
    padding-left: 0px;
    padding-right: 1px;
}

/* Responsive */
@media only screen and (min-width: 1500px) {
    .full-width-content .vc_span12 ul.products li:nth-child(5n+1), .woocommerce-page .full-width-content .vc_span12 ul.products li:nth-child(5n+1),
    .woocommerce-page .full-width-content ul.products li:nth-child(5n+1), .woocommerce-page .full-width-content .vc_span12 ul.products li:nth-child(5n+1) {
        margin-right: 2%;
        margin-left: 2%;
    }

    .woocommerce-page .full-width-content .vc_span12 ul.products li.product.last, body .full-width-content .vc_span12 ul.products li.product.last, .woocommerce-page .full-width-content ul.products li.product.last,
    .woocommerce-page .full-width-content ul.products li.product.last {
        margin-right: 0;
        margin-left: 2%;
    }
}

@media only screen and (min-width: 1001px) {

}

@media only screen and (max-width: 1500px) and (min-width: 1000px) {
    .full-width-content ul.products li:nth-child(4n+1), .woocommerce-page .full-width-content ul.products li:nth-child(4n+1) {
        margin-right: 2%;
    }

    .woocommerce-page .full-width-content ul.products li.product.last, .full-width-content ul.products li.product.last {
        margin-left: 2%;
        margin-right: 0;
    }

    body[data-header-format="left-header"].woocommerce ul.products li.product.material, body[data-header-format="left-header"].woocommerce-page ul.products li.product.material, body[data-header-format="left-header"].woocommerce ul.products li.product.material.last, body[data-header-format="left-header"].woocommerce-page ul.products li.product.material.last {
        margin-right: 0;
        margin-left: 1.3%;
    }

    body[data-header-format="left-header"].woocommerce .span_9 ul.products[data-product-style="material"] li.product.material, body[data-header-format="left-header"].woocommerce-page .span_9 ul.products[data-product-style="material"] li.product.material {
        margin: 0px 0 2% 2%;
    }

    body[data-header-format="left-header"].woocommerce .span_9 ul.products[data-product-style="material"] li.product.material:nth-child(2n+2), body[data-header-format="left-header"].woocommerce-page .span_9 ul.products[data-product-style="material"] li.product.material:nth-child(2n+2) {
        margin-left: 0%;
    }
}

@media only screen and (max-width: 1000px) and (min-width: 690px) {
    html body .full-width-content .page-title, html .woocommerce .full-width-content .woocommerce-result-count {
        padding-right: 4%;
        padding-left: 0;
    }

    html body .full-width-content .vc_span12 ul.products li:nth-child(3n+1), .woocommerce-page .full-width-content ul.products li:nth-child(3n+1) {
        margin-right: 4%;
    }

    html body .full-width-content .vc_span12 ul.products li:nth-child(2n+2), body.woocommerce-page .full-width-content ul.products li.product:nth-child(2n+2), html body .full-width-content .vc_span12 .woocommerce ul.products li:nth-child(2n+2) {
        margin-left: 4%;
        margin-right: 0;
    }

    html body .full-width-content .vc_span12 ul.products li:nth-child(3n-2), body.woocommerce-page .full-width-content ul.products li.product:nth-child(3n-2), html body .full-width-content .vc_span12 .woocommerce ul.products li:nth-child(3n-2) {
        margin-right: 4%;
    }

    body .full-width-content .vc_span12 ul.products li.product:nth-child(2n), .woocommerce-page .full-width-content ul.products li.product:nth-child(2n) {
        float: right;
    }
}

@media only screen and (min-width: 1001px) {

}

@media only screen and (min-width: 768px) {
    .woocommerce-account .woocommerce-MyAccount-navigation {
        padding-left: 30px;
        padding-right: 0;
    }
}

@media (min-width: 690px) {
    #commentform .col {
        margin-left: 2%;
        margin-right: 0;
    }

    .row.blog-recent .col {
        margin-left: 2%;
        margin-right: 0;
    }

    #copyright .col {
        margin-left: 2%;
        margin-right: 0;
    }
}

@media only screen and (max-width: 768px) {
    .woocommerce-account .woocommerce-MyAccount-content, .woocommerce-account .woocommerce-MyAccount-navigation {
        float: none;
    }

    .woocommerce ul.products li.product, .woocommerce-page ul.products li.product, .woocommerce-page[class*=columns-] ul.products li.product, .woocommerce[class*=columns-] ul.products li.product {
        float: right;
    }

    .woocommerce ul.products li.product:nth-child(2n), .woocommerce-page ul.products li.product:nth-child(2n), .woocommerce-page[class*=columns-] ul.products li.product:nth-child(2n), .woocommerce[class*=columns-] ul.products li.product:nth-child(2n) {
        float: left;
    }
}

@media only screen and (max-width: 690px) {
    .container article.post .post-content {
        padding-right: 0px !important;
    }

    body .full-width-content .vc_span12 ul.products li:nth-child(4n+1), .woocommerce-page .full-width-content ul.products li:nth-child(4n+1) {
        margin-right: 5%;
        margin-left: 4%;
    }

    body .full-width-content .vc_span12 ul.products li:nth-child(2n+2), .woocommerce-page .full-width-content ul.products li:nth-child(2n+2), body .full-width-content .vc_span12 .woocommerce ul.products li:nth-child(2n+2) {
        margin-left: 5%;
        margin-right: 0;
    }

    body .full-width-content .vc_span12 ul.products li:nth-child(2n+3), .woocommerce-page .full-width-content ul.products li:nth-child(2n+3) {
        margin-right: 5%;
        margin-left: 4%;
    }

    .woocommerce-page .full-width-content ul.products li.product.last, body .full-width-content .vc_span12 ul.products li.product.last {
        margin-left: 5%;
        margin-right: 0;
    }
}

@media only screen and (max-width: 1000px) and (min-width: 1px) {
    a > .sf-sub-indicator {
        left: 0px !important;
        right: auto !important;
    }

    #single-meta ul {
        margin-right: 0px;
    }

    .single #single-meta ul {
        float: right;
    }

    .single .blog-title #single-meta ul li {
        float: left;
    }

    body.single-post .blog-title #single-meta ul li:last-child {
        margin: 5px !important;
    }

    .single #single-meta ul li.meta-share-count .nectar-social {
        left: auto !important;
        right: 0 !important;
        text-align: right;
    }

    body.woocommerce ul.products li.product, body.woocommerce-page ul.products li.product, .woocommerce .related ul.products li.product, .woocommerce .related ul li.product, .woocommerce .upsells.products ul.products li.product,
    .woocommerce .upsells.products ul li.product, .woocommerce-page .related ul.products li.product, .woocommerce-page .related ul li.product, .woocommerce-page .upsells.products ul.products li.product,
    .woocommerce-page .upsells.products ul li.product, body.woocommerce .span_9 ul.products li.product, body.woocommerce-page .span_9 ul.products li.product, body .woocommerce ul.products li.product, body .woocommerce-page ul.products li.product,
    html .woocommerce .products.related .product, html .woocommerce .products.upsells .product, html .woocommerce-page.columns-3 ul.products li.product, html .woocommerce.columns-3 ul.products li.product {
        margin: 0px 0 25px 4%;
    }

    .woocommerce .span_9 ul.products li.product:nth-child(2n+2), .woocommerce-page .span_9 ul.products li.product:nth-child(2n+2), body .woocommerce ul.products li.product:nth-child(2n+2),
    body .woocommerce-page ul.products li.product:nth-child(2n+2), body.woocommerce ul.products li:nth-child(2n+2) {
        margin-left: 0;
    }

    body #slide-out-widget-area a.slide_out_area_close {
        left: 22px;
        right: auto;
    }

    .pricing-table[data-style="flat-alternative"].two-cols > div:nth-child(2), .pricing-table[data-style="flat-alternative"].three-cols > div:nth-child(2),
    .pricing-table[data-style="flat-alternative"].four-cols > div:nth-child(2n+2), .pricing-table[data-style="flat-alternative"].five-cols > div:nth-child(2n+2) {
        margin-left: 0 !important;
    }

    body .woocommerce ul.products li.product.material, body.woocommerce-page ul.products li.product.material, html .woocommerce .span_9 ul.products li.product.material, html .woocommerce-page .span_9 ul.products li.product.material, body .woocommerce.columns-1 ul.products li.product.material {
        margin: 0px 0 2% 2%;
    }

    body.woocommerce ul.products li.product, body.woocommerce-page ul.products li.product, .woocommerce .related ul.products li.product, .woocommerce .related ul li.product, .woocommerce .upsells.products ul.products li.product, .woocommerce .upsells.products ul li.product, .woocommerce-page .related ul.products li.product, .woocommerce-page .related ul li.product, .woocommerce-page .upsells.products ul.products li.product, .woocommerce-page .upsells.products ul li.product, body.woocommerce .span_9 ul.products li.product, body.woocommerce-page .span_9 ul.products li.product, body .woocommerce ul.products li.product, body .woocommerce-page ul.products li.product, html .woocommerce .products.related .product, html .woocommerce .products.upsells .product, html .woocommerce-page.columns-3 ul.products li.product, html .woocommerce.columns-3 ul.products li.product {
        margin: 0px 0 25px 4%;
    }

    .woocommerce .span_9 ul.products li.product:nth-child(2n+2), .woocommerce-page .span_9 ul.products li.product:nth-child(2n+2), body .woocommerce ul.products li.product:nth-child(2n+2), body .woocommerce-page ul.products li.product:nth-child(2n+2), body.woocommerce ul.products li:nth-child(2n+2) {
        margin-left: 0px;
    }

    body .woocommerce ul.products[data-product-style="material"] li:nth-child(2n+2), body.woocommerce-page ul.products[data-product-style="material"] li:nth-child(2n+2) {
        margin-left: 0% !important;
    }

    body .woocommerce ul.products[data-product-style="material"] li:nth-child(2n+1), body.woocommerce-page ul.products[data-product-style="material"] li:nth-child(2n+1) {
        margin-left: 2% !important;
        margin-right: 0 !important;
    }

    .nectar-recent-posts-slider .inner-wrap {
        left: 0;
    }

    .full-width-content .nectar-recent-posts-slider .recent-post-container .inner-wrap {
        margin-right: 10px;
    }
}

@media only screen and (max-width: 480px) {
    .single .blog-title #single-meta ul {
        float: right !important;
    }
}

@media only screen and (max-width: 470px) {
    body .woocommerce ul.products[data-product-style="material"] li.product.material, body.woocommerce-page ul.products[data-product-style="material"] li.product.material, html .woocommerce .span_9 ul.products li.product.material, html .woocommerce-page .span_9 ul.products li.product.material, body .woocommerce.columns-1 ul.products li.product.material {
        margin-left: 0% !important;
    }
}


/*nectar*/

#header-outer[data-format="menu-left-aligned"] .row .col.span_9 { float: right;}
body #header-outer[data-format="menu-left-aligned"] .row .col.span_3 { float: right; margin-left: 25px; margin-right: 0;}
#header-outer[data-format="menu-left-aligned"] .row .right-aligned-menu-items {
    float: left;
}

.main-content > .row > .vc_row-o-equal-height.vc_row-flex {
    direction: ltr;
}